@@ -27,13 +27,15 @@ from alembic import context, op
 def upgrade():
     if context.get_context().dialect.name != 'sqlite':
         op.add_column('rses', sa.Column('staging_area', sa.Boolean(name='RSE_STAGING_AREA_CHK'), default=False))
-        op.drop_constraint('REQUESTS_TYPE_CHK', 'requests')
+
+    if context.get_context().dialect.name not in ('sqlite', 'mysql'):
+        op.drop_constraint('REQUESTS_TYPE_CHK', 'requests', type_='check')
         op.create_check_constraint(name='REQUESTS_TYPE_CHK', source='requests', condition="request_type in ('U', 'D', 'T', 'I', '0')")
 
 
 def downgrade():
-    if context.get_context().dialect.name != 'sqlite':
-        op.drop_constraint('RSE_STAGING_AREA_CHK', 'rses')
-        op.drop_constraint('REQUESTS_TYPE_CHK', 'requests')
+    if context.get_context().dialect.name not in ('sqlite', 'mysql'):
+        op.drop_constraint('RSE_STAGING_AREA_CHK', 'rses', type_='check')
+        op.drop_constraint('REQUESTS_TYPE_CHK', 'requests', type_='check')
         op.create_check_constraint(name='REQUESTS_TYPE_CHK', source='requests', condition="request_type in ('U', 'D', 'T')")
     op.drop_column('rses', 'staging_area')
