@@ -148,6 +148,14 @@ class Default(protocol.RSEProtocol):
 
         self.__ctx = gfal2.creat_context()
         self.__ctx.set_opt_string_list("SRM PLUGIN", "TURL_PROTOCOLS", ["gsiftp", "rfio", "gsidcap", "dcap", "kdcap"])
+        endpoint_basepath = self.path2pfn(self.attributes['prefix'])
+
+        try:
+            ret = self.__gfal2_exist(endpoint_basepath)
+            if not ret == 0:
+                raise exception.RSEAccessDenied()
+        except Exception as e:
+            raise exception.RSEAccessDenied(e)
 
     def get(self, path, dest):
         """
@@ -314,7 +322,7 @@ class Default(protocol.RSEProtocol):
             ret = ctx.filecopy(params, str(src), str(dest))
             return ret
         except gfal2.GError as e:
-            if e.code == errno.ENOENT or e.code == errno.EINVAL:
+            if e.code == errno.ENOENT or 'No such file' in e.message:
                 raise exception.SourceNotFound(e)
             raise exception.RucioException(e)
 
@@ -339,7 +347,7 @@ class Default(protocol.RSEProtocol):
                     return ret
             return ret
         except gfal2.GError as e:
-            if e.code == errno.ENOENT or e.code == errno.EINVAL:
+            if e.code == errno.ENOENT or 'No such file' in e.message:
                 raise exception.SourceNotFound(e)
             raise exception.RucioException(e)
 
@@ -361,7 +369,7 @@ class Default(protocol.RSEProtocol):
                 return 0
             return -1
         except gfal2.GError as e:
-            if e.code == errno.ENOENT or e.code == errno.EINVAL:
+            if e.code == errno.ENOENT or 'No such file' in e.message:
                 return -1
             raise exception.RucioException(e)
 
@@ -381,10 +389,16 @@ class Default(protocol.RSEProtocol):
 
         try:
             dir_name = os.path.dirname(new_path)
-            ctx.mkdir(str(dir_name), 0775)
+            # This function will be removed soon. gfal2 will create parent dir automatically.
+            try:
+                ctx.mkdir(str(dir_name), 0775)
+            except:
+                pass
             ret = ctx.rename(str(path), str(new_path))
             return ret
         except gfal2.GError as e:
+            if e.code == errno.ENOENT or 'No such file' in e.message:
+                raise exception.SourceNotFound(e)
             raise exception.RucioException(e)
 
     def get_space_usage(self):
