@@ -15,7 +15,6 @@
 import copy
 import os
 
-from dogpile.cache import make_region
 from urlparse import urlparse
 
 from rucio.common import exception, utils
@@ -23,14 +22,6 @@ from rucio.common import exception, utils
 DEFAULT_PROTOCOL = 1
 
 
-# Preparing region for dogpile.cache
-region = make_region(function_key_generator=utils.my_key_generator).configure(
-    'dogpile.cache.memory',
-    expiration_time=3600,
-)
-
-
-@region.cache_on_arguments(namespace='rse_info')  # Sets the dogpile.cache for this method based on the provided RSE name
 def get_rse_info(rse, session=None):
     """ Returns all protocol related RSE attributes.
 
@@ -60,7 +51,12 @@ def get_rse_info(rse, session=None):
         :raises RSENotFound: if the provided RSE coud not be found in the database.
     """
     # __request_rse_info will be assigned when the module is loaded as it depends on the rucio environment (server or client)
-    return __request_rse_info(rse, session=session)  # NOQA
+    # __request_rse_info, rse_region are defined in /rucio/rse/__init__.py
+    rse_info = rse_region.get(str(rse), ignore_expiration=True)   # NOQA
+    if not rse_info:  # no cached entry found
+        rse_info = __request_rse_info(str(rse), session=session)  # NOQA
+        rse_region.set(str(rse), rse_info)  # NOQA
+    return rse_info
 
 
 def select_protocol(rse_settings, operation, scheme=None):
