@@ -10,6 +10,7 @@
 # - Angelos Molfetas, <angelos.molfetas@cern.ch>, 2012
 # - Thomas Beermann, <thomas.beermann@cern.ch>, 2012
 # - Joaquin Bogado, <joaquin.bogado@cern.ch>, 2014
+# - Cheng-Hsi Chao, <cheng-hsi.chao@cern.ch>, 2014
 
 from os import remove
 
@@ -18,7 +19,7 @@ import re
 
 from rucio import version
 from rucio.common.config import config_get
-from rucio.tests.common import execute, account_name_generator, rse_name_generator, file_generator
+from rucio.tests.common import execute, account_name_generator, rse_name_generator, file_generator, scope_name_generator
 
 
 class TestBinRucio():
@@ -36,19 +37,19 @@ class TestBinRucio():
         self.def_rse = 'MOCK4'
 
     def test_rucio_version(self):
-        """CLI: Get Version"""
+        """CLIENT(USER): Rucio version"""
         cmd = 'bin/rucio --version'
         exitcode, out, err = execute(cmd)
         nose.tools.assert_equal(err, 'rucio %s\n' % version.version_string())
 
     def test_rucio_ping(self):
-        """PING (CLI): Rucio ping"""
+        """CLIENT(USER): Rucio ping"""
         cmd = 'rucio --host %s ping' % self.host
         print self.marker + cmd
         exitcode, out, err = execute(cmd)
 
     def test_add_account(self):
-        """ACCOUNT (CLI): Add account"""
+        """CLIENT(ADMIN): Add account"""
         tmp_val = account_name_generator()
         cmd = 'rucio-admin account add %s' % tmp_val
         print self.marker + cmd
@@ -57,7 +58,7 @@ class TestBinRucio():
         nose.tools.assert_equal('Added new account: %s\n' % tmp_val, out)
 
     def test_whoami(self):
-        """ACCOUNT (CLI): Test whoami"""
+        """CLIENT(USER): Rucio whoami"""
         cmd = 'rucio whoami'
         print self.marker + cmd
         exitcode, out, err = execute(cmd)
@@ -65,7 +66,7 @@ class TestBinRucio():
         nose.tools.assert_regexp_matches(out, re.compile('.*account.*'))
 
     def test_add_identity(self):
-        """ACCOUNT (CLI): Test add identity"""
+        """CLIENT(ADMIN): Add identity"""
         tmp_val = account_name_generator()
         cmd = 'rucio-admin account add %s' % tmp_val
         exitcode, out, err = execute(cmd)
@@ -76,19 +77,44 @@ class TestBinRucio():
         print out,
         nose.tools.assert_equal('Added new identity to account: jdoe@CERN.CH-%s\n' % tmp_val, out)
 
-    def test_add_scope(self):
-        """ACCOUNT (CLI): Test add identity"""
-        tmp_val = account_name_generator()
-        cmd = 'rucio-admin account add %s' % tmp_val
+    def test_del_identity(self):
+        """CLIENT(ADMIN): Test del identity"""
+        tmp_acc = account_name_generator()
+
+        # create account
+        cmd = 'rucio-admin account add %s' % tmp_acc
         exitcode, out, err = execute(cmd)
-        cmd = 'rucio-admin identity add --account %s --type GSS --id jdoe@CERN.CH --email jdoe@CERN.CH' % tmp_val
+        # add identity to account
+        cmd = 'rucio-admin identity add --account %s --type GSS --id jdoe@CERN.CH --email jdoe@CERN.CH' % tmp_acc
+        exitcode, out, err = execute(cmd)
+        # delete identity from account
+        cmd = 'rucio-admin identity delete --account %s --type GSS --id jdoe@CERN.CH' % tmp_acc
         print self.marker + cmd
         exitcode, out, err = execute(cmd)
-        print out,
-        nose.tools.assert_equal('Added new identity to account: jdoe@CERN.CH-%s\n' % tmp_val, out)
+        print out, err
+        nose.tools.assert_equal('Deleted identity: jdoe@CERN.CH\n', out)
+        # list identities for account
+        cmd = 'rucio-admin account list-identities %s' % (tmp_acc)
+        print self.marker + cmd
+        print cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        nose.tools.assert_equal('', out)
+
+    def test_add_scope(self):
+        """CLIENT(ADMIN): Add scope"""
+        tmp_scp = scope_name_generator()
+        tmp_acc = account_name_generator()
+        cmd = 'rucio-admin account add %s' % tmp_acc
+        exitcode, out, err = execute(cmd)
+        cmd = 'rucio-admin scope add --account %s --scope %s' % (tmp_acc, tmp_scp)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        nose.tools.assert_equal('Added new scope to account: %s-%s\n' % (tmp_scp, tmp_acc), out)
 
     def test_add_rse(self):
-        """RSE (CLI): Add RSE"""
+        """CLIENT(ADMIN): Add RSE"""
         tmp_val = rse_name_generator()
         cmd = 'rucio-admin rse add %s' % tmp_val
         print self.marker + cmd
@@ -97,7 +123,7 @@ class TestBinRucio():
         nose.tools.assert_equal('Added new RSE: %s\n' % tmp_val, out)
 
     def test_list_rses(self):
-        """RSE (CLI): List RSEs"""
+        """CLIENT(ADMIN): List RSEs"""
         tmp_val = rse_name_generator()
         cmd = 'rucio-admin rse add %s' % tmp_val
         exitcode, out, err = execute(cmd)
@@ -108,7 +134,7 @@ class TestBinRucio():
         nose.tools.assert_regexp_matches(out, re.compile('.*%s.*' % tmp_val))
 
     def test_upload(self):
-        """RSE (CLI): Upload"""
+        """CLIENT(USER): Upload"""
         tmp_val = rse_name_generator()
         cmd = 'rucio-admin rse add %s' % tmp_val
         exitcode, out, err = execute(cmd)
@@ -118,14 +144,14 @@ class TestBinRucio():
         print out,
 
     def test_download(self):
-        """RSE (CLI): Download"""
+        """CLIENT(USER): Download"""
         cmd = 'rucio download'
         print self.marker + cmd
         exitcode, out, err = execute(cmd)
         print out,
 
     def test_upload_file(self):
-        """UPLOAD (CLI): File"""
+        """CLIENT(USER): Rucio upload files"""
         tmp_file1 = file_generator()
         tmp_file2 = file_generator()
         tmp_file3 = file_generator()
@@ -139,8 +165,78 @@ class TestBinRucio():
         remove(tmp_file3)
         nose.tools.assert_not_equal(re.search("File {0}:{1} successfully uploaded on the storage".format(self.user, tmp_file1[5:]), out), None)
 
+    def test_upload_repeated_file(self):
+        """CLIENT(USER): Rucio upload repeated files"""
+        # One of the files to upload is already catalogued but was removed
+        tmp_file1 = file_generator()
+        tmp_file2 = file_generator()
+        tmp_file3 = file_generator()
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # get the rule for the file
+        cmd = "rucio list-rules --did {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1[5:])
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        rule = out
+        # delete the file from the catalog
+        cmd = "rucio delete-rule {0}".format(rule)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        # delete the fisical file
+        cmd = "find /tmp/rucio_rse/ -name {0} |xargs rm".format(tmp_file1[5:])
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} {3} {4}'.format(self.def_rse, self.user, tmp_file1, tmp_file2, tmp_file3)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        remove(tmp_file2)
+        remove(tmp_file3)
+        nose.tools.assert_not_equal(re.search("File {0}:{1} successfully uploaded on the storage".format(self.user, tmp_file2[5:]), out), None)
+
+    def test_upload_repeated_file_dataset(self):
+        """CLIENT(USER): Rucio upload repeated files to dataset"""
+        # One of the files to upload is already in the dataset
+        tmp_file1 = file_generator()
+        tmp_file2 = file_generator()
+        tmp_file3 = file_generator()
+        tmp_dsn = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
+        # Adding files to a new dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} --did {3}'.format(self.def_rse, self.user, tmp_file1, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # upload the files to the dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} {3} {4} --did {5}'.format(self.def_rse, self.user, tmp_file1, tmp_file2, tmp_file3, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        remove(tmp_file2)
+        remove(tmp_file3)
+        # searching for the file in the new dataset
+        cmd = 'rucio list-files {0}'.format(tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # tmp_file1 must be in the dataset
+        nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file1[5:]), out), None)
+        # tmp_file3 must be in the dataset
+        nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file3[5:]), out), None)
+
     def test_upload_file_dataset(self):
-        """UPLOAD (CLI): File to Dataset"""
+        """CLIENT(USER): Rucio upload files to dataset"""
         tmp_file1 = file_generator()
         tmp_file2 = file_generator()
         tmp_file3 = file_generator()
@@ -163,7 +259,7 @@ class TestBinRucio():
         nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file1[5:]), out), None)
 
     def test_create_dataset(self):
-        """DATASET (CLI): creation"""
+        """CLIENT(USER): Rucio add dataset"""
         tmp_name = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
         cmd = 'rucio add-dataset ' + tmp_name
         print self.marker + cmd
@@ -172,7 +268,7 @@ class TestBinRucio():
         nose.tools.assert_not_equal(re.search('Added ' + tmp_name, out), None)
 
     def test_add_files_to_dataset(self):
-        """DATASET (CLI): add files"""
+        """CLIENT(USER): Rucio add files to dataset"""
         tmp_file1 = file_generator()
         tmp_file2 = file_generator()
         tmp_dataset = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
@@ -199,7 +295,7 @@ class TestBinRucio():
         nose.tools.assert_not_equal(re.search(tmp_file1[5:], out), None)
 
     def test_download_file(self):
-        """DATASET (CLI): download files"""
+        """CLIENT(USER): Rucio download files"""
         tmp_file1 = file_generator()
         # add files
         cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -211,10 +307,15 @@ class TestBinRucio():
         print self.marker + cmd
         exitcode, out, err = execute(cmd)
         print out, err
-        nose.tools.assert_not_equal(re.search('DID {0}:{1}'.format(self.user, tmp_file1[5:]), out), None)
+        # search for the files with ls
+        cmd = 'ls /tmp/{0}'.format(self.user)   # search in /tmp/mock
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out, err
+        nose.tools.assert_not_equal(re.search(tmp_file1[5:], out), None)
 
     def test_download_dataset(self):
-        """DATASET (CLI): download dataset"""
+        """CLIENT(USER): Rucio download dataset"""
         tmp_file1 = file_generator()
         tmp_dataset = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
         # add files
@@ -245,7 +346,7 @@ class TestBinRucio():
         nose.tools.assert_not_equal(re.search(search, out), None)
 
     def test_create_rule(self):
-        """DATASET (CLI): rule creation"""
+        """CLIENT(USER): Rucio add rule"""
         tmp_file1 = file_generator()
         # add files
         cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -299,7 +400,7 @@ class TestBinRucio():
         nose.tools.assert_not_equal(re.search(rule, out), None)
 
     def test_delete_rule(self):
-        """DATASET (CLI): rule deletion"""
+        """CLIENT(USER): rule deletion"""
         tmp_file1 = file_generator()
         # add files
         cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -345,7 +446,7 @@ class TestBinRucio():
         nose.tools.assert_equal('', out)
 
     def test_add_file_twice(self):
-        """DATASET (CLI): Add file twice"""
+        """CLIENT(USER): Add file twice"""
         tmp_file1 = file_generator()
         # add file twice
         cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -357,7 +458,7 @@ class TestBinRucio():
         nose.tools.assert_equal(re.search("File {0}:{1} successfully uploaded on the storage".format(self.user, tmp_file1[5:]), out), None)
 
     def test_add_delete_add_file(self):
-        """DATASET (CLI): Add/Delete/Add"""
+        """CLIENT(USER): Add/Delete/Add"""
         tmp_file1 = file_generator()
         # add file
         cmd = 'rucio upload --rse {0} --scope {1} --files {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -391,3 +492,114 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print out, err
         nose.tools.assert_equal(re.search("File {0}:{1} successfully uploaded on the storage".format(self.user, tmp_file1[5:]), out), None)
+
+    def test_attach_files_dataset(self):
+        """CLIENT(USER): Rucio attach files to dataset"""
+        # Attach files to a dataset using the attach method
+        tmp_file1 = file_generator()
+        tmp_file2 = file_generator()
+        tmp_file3 = file_generator()
+        tmp_dsn = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
+        # Adding files to a new dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} --did {3}'.format(self.def_rse, self.user, tmp_file1, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # upload the files
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} {3}'.format(self.def_rse, self.user, tmp_file2, tmp_file3)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        remove(tmp_file2)
+        remove(tmp_file3)
+        # attach the files to the dataset
+        cmd = 'rucio attach --to {0} {1}:{2} {1}:{3}'.format(tmp_dsn, self.user, tmp_file2[5:], tmp_file3[5:])  # triming '/tmp/' from filenames
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # searching for the file in the new dataset
+        cmd = 'rucio list-files {0}'.format(tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # tmp_file2 must be in the dataset
+        nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file2[5:]), out), None)
+        # tmp_file3 must be in the dataset
+        nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file3[5:]), out), None)
+
+    def test_detach_files_dataset(self):
+        """CLIENT(USER): Rucio detach files to dataset"""
+        # Attach files to a dataset using the attach method
+        tmp_file1 = file_generator()
+        tmp_file2 = file_generator()
+        tmp_file3 = file_generator()
+        tmp_dsn = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
+        # Adding files to a new dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} {3} {4} --did {5}'.format(self.def_rse, self.user, tmp_file1, tmp_file2, tmp_file3, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        remove(tmp_file2)
+        remove(tmp_file3)
+        # detach the files to the dataset
+        cmd = 'rucio detach --from {0} {1}:{2} {1}:{3}'.format(tmp_dsn, self.user, tmp_file2[5:], tmp_file3[5:])  # triming '/tmp/' from filenames
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # searching for the file in the new dataset
+        cmd = 'rucio list-files {0}'.format(tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        # tmp_file1 must be in the dataset
+        nose.tools.assert_not_equal(re.search("{0}:{1}".format(self.user, tmp_file1[5:]), out), None)
+        # tmp_file3 must be in the dataset
+        nose.tools.assert_equal(re.search("{0}:{1}".format(self.user, tmp_file3[5:]), out), None)
+
+    def test_attach_file_twice(self):
+        """CLIENT(USER): Rucio attach a file twice"""
+        # Attach files to a dataset using the attach method
+        tmp_file1 = file_generator()
+        tmp_dsn = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
+        # Adding files to a new dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} --did {3}'.format(self.def_rse, self.user, tmp_file1, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        # attach the files to the dataset
+        cmd = 'rucio attach --to {0} {1}:{2}'.format(tmp_dsn, self.user, tmp_file1[5:])  # triming '/tmp/' from filenames
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        nose.tools.assert_not_equal(re.search("Failed to attach data identifier", err), None)
+
+    def test_detach_non_existing_file(self):
+        """CLIENT(USER): Rucio detach a non existing file"""
+        tmp_file1 = file_generator()
+        tmp_dsn = self.user + ':DSet' + rse_name_generator()  # something like mock:DSetMOCK_S0M37HING
+        # Adding files to a new dataset
+        cmd = 'rucio upload --rse {0} --scope {1} --files {2} --did {3}'.format(self.def_rse, self.user, tmp_file1, tmp_dsn)
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        remove(tmp_file1)
+        # attach the files to the dataset
+        cmd = 'rucio detach --from {0} {1}:{2}'.format(tmp_dsn, self.user, 'file_ghost')  # triming '/tmp/' from filenames
+        print self.marker + cmd
+        exitcode, out, err = execute(cmd)
+        print out
+        print err
+        nose.tools.assert_not_equal(re.search("Failed to detach data identifier", err), None)
