@@ -178,10 +178,10 @@ class TestRSEClient():
 
         files2 = [{'scope': tmp_scope, 'name': 'file_%s' % generate_uuid(), 'bytes': 1L, 'adler32': '0cc737eb', 'meta': {'events': 10}} for i in xrange(nbfiles)]
         with assert_raises(RessourceTemporaryUnavailable):
-            replica_client.add_replicas(rse=renamed_rse, files=files2)
+            replica_client.add_replicas(rse=renamed_rse, files=files2, ignore_availability=False)
 
         with assert_raises(RessourceTemporaryUnavailable):
-            replica_client.delete_replicas(rse=renamed_rse, files=files1)
+            replica_client.delete_replicas(rse=renamed_rse, files=files1, ignore_availability=False)
 
     def test_list_rses(self):
         """ RSE (CLIENTS): try to list rses."""
@@ -212,7 +212,7 @@ class TestRSEClient():
                       'prefix': '/the/one/with/all/the/files',
                       'impl': 'rucio.rse.protocols.SomeProtocol.SomeImplementation',
                       'domains': {
-                          'lan': {'read': 1,
+                          'lan': {'read': 4,
                                   'write': 1,
                                   'delete': 0
                                   }
@@ -396,7 +396,7 @@ class TestRSEClient():
                                       'domains': {
                                           'lan': {'read': 4,
                                                   'write': 99,
-                                                  'delete': 1
+                                                  'delete': -1
                                                   }
                                       },
                                       'extended_attributes': 'TheOneWithAllTheRest'
@@ -1503,9 +1503,10 @@ class TestRSEClient():
     def test_set_rse_usage(self):
         """ RSE (CLIENTS): Test the update of RSE usage."""
         assert_equal(self.client.set_rse_usage(rse='MOCK', source='srm', used=999200L, free=800L), True)
-        usage = self.client.get_rse_usage(rse='MOCK')
-        print usage
-        assert_equal(usage['total'], 1000000)
+        usages = self.client.get_rse_usage(rse='MOCK')
+        for usage in usages:
+            print usage
+            assert_equal(usage['total'], 1000000)
         assert_equal(self.client.set_rse_usage(rse='MOCK', source='srm', used=999920L, free=80L), True)
         for usage in self.client.list_rse_usage_history(rse='MOCK'):
             assert_equal(usage['free'], 80)
